[nautilus-actions] Advanced conditions tab is renamed as just Schemes



commit 54e316cefbf2cd41a0d7dbbdee508d4369be9a6a
Author: Pierre Wieser <pwieser trychlos org>
Date:   Mon Apr 12 06:24:20 2010 +0200

    Advanced conditions tab is renamed as just Schemes

 ChangeLog                                          |   10 ++
 src/nact/Makefile.am                               |    4 +-
 src/nact/nact-icommand-tab.c                       |    4 +-
 .../{nact-iadvanced-tab.c => nact-ischemes-tab.c}  |   88 ++++++++++----------
 .../{nact-iadvanced-tab.h => nact-ischemes-tab.h}  |   42 +++++-----
 src/nact/nact-main-tab.h                           |    2 +-
 src/nact/nact-main-window.c                        |   24 +++---
 7 files changed, 92 insertions(+), 82 deletions(-)
---
diff --git a/ChangeLog b/ChangeLog
index e8f3326..4afa3cf 100644
--- a/ChangeLog
+++ b/ChangeLog
@@ -83,6 +83,16 @@
 
 2010-04-12 Pierre Wieser <pwieser trychlos org>
 
+	"Advanced conditions" tab is renamed as "Schemes".
+
+	* src/nact/nact-iadvanced-tab.c: Renamed as src/nact/nact-ischemes-tab.c.
+	* src/nact/nact-iadvanced-tab.h: Renamed as src/nact/nact-ischemes-tab.h.
+
+	* src/nact/Makefile.am:
+	* src/nact/nact-icommand-tab.c:
+	* src/nact/nact-main-tab.h:
+	* src/nact/nact-main-window.c: Updated accordingly.
+
 	Move item properties to their own tab.
 
 	* src/nact/nact-iproperties-tab.c:
diff --git a/src/nact/Makefile.am b/src/nact/Makefile.am
index 7b94580..28add0d 100644
--- a/src/nact/Makefile.am
+++ b/src/nact/Makefile.am
@@ -93,8 +93,6 @@ nautilus_actions_config_tool_SOURCES = \
 	nact-iactions-list-priv.h							\
 	nact-iaction-tab.c									\
 	nact-iaction-tab.h									\
-	nact-iadvanced-tab.c								\
-	nact-iadvanced-tab.h								\
 	nact-ifolders-tab.c									\
 	nact-ifolders-tab.h									\
 	nact-icommand-tab.c									\
@@ -105,6 +103,8 @@ nautilus_actions_config_tool_SOURCES = \
 	nact-iprefs.h										\
 	nact-iproperties-tab.c								\
 	nact-iproperties-tab.h								\
+	nact-ischemes-tab.c									\
+	nact-ischemes-tab.h									\
 	nact-main.c											\
 	nact-main-menubar.c									\
 	nact-main-menubar.h									\
diff --git a/src/nact/nact-icommand-tab.c b/src/nact/nact-icommand-tab.c
index 2c2a294..bab2d53 100644
--- a/src/nact/nact-icommand-tab.c
+++ b/src/nact/nact-icommand-tab.c
@@ -50,7 +50,7 @@
 #include "nact-main-tab.h"
 #include "nact-icommand-tab.h"
 #include "nact-iconditions-tab.h"
-#include "nact-iadvanced-tab.h"
+#include "nact-ischemes-tab.h"
 
 /* private interface data
  */
@@ -686,7 +686,7 @@ parse_parameters( NactICommandTab *instance )
 
 	nact_iconditions_tab_get_isfiledir( NACT_ICONDITIONS_TAB( instance ), &is_file, &is_dir );
 	accept_multiple = nact_iconditions_tab_get_multiple( NACT_ICONDITIONS_TAB( instance ));
-	scheme_list = nact_iadvanced_tab_get_schemes( NACT_IADVANCED_TAB( instance ));
+	scheme_list = nact_ischemes_tab_get_schemes( NACT_ISCHEMES_TAB( instance ));
 
 	separator = g_strdup_printf( " %s/", ex_path );
 	start = g_strdup_printf( "%s/", ex_path );
diff --git a/src/nact/nact-iadvanced-tab.c b/src/nact/nact-ischemes-tab.c
similarity index 64%
rename from src/nact/nact-iadvanced-tab.c
rename to src/nact/nact-ischemes-tab.c
index 06b8a84..0532195 100644
--- a/src/nact/nact-iadvanced-tab.c
+++ b/src/nact/nact-ischemes-tab.c
@@ -37,11 +37,11 @@
 #include "base-window.h"
 #include "nact-main-tab.h"
 #include "nact-schemes-list.h"
-#include "nact-iadvanced-tab.h"
+#include "nact-ischemes-tab.h"
 
 /* private interface data
  */
-struct NactIAdvancedTabInterfacePrivate {
+struct NactISchemesTabInterfacePrivate {
 	void *empty;						/* so that gcc -pedantic is happy */
 };
 
@@ -49,17 +49,17 @@ static gboolean st_initialized = FALSE;
 static gboolean st_finalized = FALSE;
 
 static GType         register_type( void );
-static void          interface_base_init( NactIAdvancedTabInterface *klass );
-static void          interface_base_finalize( NactIAdvancedTabInterface *klass );
+static void          interface_base_init( NactISchemesTabInterface *klass );
+static void          interface_base_finalize( NactISchemesTabInterface *klass );
 
-static void          runtime_init_connect_signals( NactIAdvancedTab *instance, GtkTreeView *listview );
-static void          on_tab_updatable_selection_changed( NactIAdvancedTab *instance, gint count_selected );
-static void          on_tab_updatable_enable_tab( NactIAdvancedTab *instance, NAObjectItem *item );
-static gboolean      tab_set_sensitive( NactIAdvancedTab *instance );
-static GtkTreeView  *get_schemes_tree_view( NactIAdvancedTab *instance );
+static void          runtime_init_connect_signals( NactISchemesTab *instance, GtkTreeView *listview );
+static void          on_tab_updatable_selection_changed( NactISchemesTab *instance, gint count_selected );
+static void          on_tab_updatable_enable_tab( NactISchemesTab *instance, NAObjectItem *item );
+static gboolean      tab_set_sensitive( NactISchemesTab *instance );
+static GtkTreeView  *get_schemes_tree_view( NactISchemesTab *instance );
 
 GType
-nact_iadvanced_tab_get_type( void )
+nact_ischemes_tab_get_type( void )
 {
 	static GType iface_type = 0;
 
@@ -73,11 +73,11 @@ nact_iadvanced_tab_get_type( void )
 static GType
 register_type( void )
 {
-	static const gchar *thisfn = "nact_iadvanced_tab_register_type";
+	static const gchar *thisfn = "nact_ischemes_tab_register_type";
 	GType type;
 
 	static const GTypeInfo info = {
-		sizeof( NactIAdvancedTabInterface ),
+		sizeof( NactISchemesTabInterface ),
 		( GBaseInitFunc ) interface_base_init,
 		( GBaseFinalizeFunc ) interface_base_finalize,
 		NULL,
@@ -90,7 +90,7 @@ register_type( void )
 
 	g_debug( "%s", thisfn );
 
-	type = g_type_register_static( G_TYPE_INTERFACE, "NactIAdvancedTab", &info, 0 );
+	type = g_type_register_static( G_TYPE_INTERFACE, "NactISchemesTab", &info, 0 );
 
 	g_type_interface_add_prerequisite( type, BASE_WINDOW_TYPE );
 
@@ -98,24 +98,24 @@ register_type( void )
 }
 
 static void
-interface_base_init( NactIAdvancedTabInterface *klass )
+interface_base_init( NactISchemesTabInterface *klass )
 {
-	static const gchar *thisfn = "nact_iadvanced_tab_interface_base_init";
+	static const gchar *thisfn = "nact_ischemes_tab_interface_base_init";
 
 	if( !st_initialized ){
 
 		g_debug( "%s: klass=%p", thisfn, ( void * ) klass );
 
-		klass->private = g_new0( NactIAdvancedTabInterfacePrivate, 1 );
+		klass->private = g_new0( NactISchemesTabInterfacePrivate, 1 );
 
 		st_initialized = TRUE;
 	}
 }
 
 static void
-interface_base_finalize( NactIAdvancedTabInterface *klass )
+interface_base_finalize( NactISchemesTabInterface *klass )
 {
-	static const gchar *thisfn = "nact_iadvanced_tab_interface_base_finalize";
+	static const gchar *thisfn = "nact_ischemes_tab_interface_base_finalize";
 
 	if( st_initialized && !st_finalized ){
 
@@ -128,29 +128,29 @@ interface_base_finalize( NactIAdvancedTabInterface *klass )
 }
 
 void
-nact_iadvanced_tab_initial_load_toplevel( NactIAdvancedTab *instance )
+nact_ischemes_tab_initial_load_toplevel( NactISchemesTab *instance )
 {
-	static const gchar *thisfn = "nact_iadvanced_tab_initial_load_toplevel";
+	static const gchar *thisfn = "nact_ischemes_tab_initial_load_toplevel";
 
 	if( st_initialized && !st_finalized ){
 
 		g_debug( "%s: instance=%p", thisfn, ( void * ) instance );
-		g_return_if_fail( NACT_IS_IADVANCED_TAB( instance ));
+		g_return_if_fail( NACT_IS_ISCHEMES_TAB( instance ));
 
 		nact_schemes_list_create_model( get_schemes_tree_view( instance ), TRUE );
 	}
 }
 
 void
-nact_iadvanced_tab_runtime_init_toplevel( NactIAdvancedTab *instance )
+nact_ischemes_tab_runtime_init_toplevel( NactISchemesTab *instance )
 {
-	static const gchar *thisfn = "nact_iadvanced_tab_runtime_init_toplevel";
+	static const gchar *thisfn = "nact_ischemes_tab_runtime_init_toplevel";
 	GtkTreeView *listview;
 
 	if( st_initialized && !st_finalized ){
 
 		g_debug( "%s: instance=%p", thisfn, ( void * ) instance );
-		g_return_if_fail( NACT_IS_IADVANCED_TAB( instance ));
+		g_return_if_fail( NACT_IS_ISCHEMES_TAB( instance ));
 
 		listview = get_schemes_tree_view( instance );
 		runtime_init_connect_signals( instance, listview );
@@ -159,14 +159,14 @@ nact_iadvanced_tab_runtime_init_toplevel( NactIAdvancedTab *instance )
 }
 
 static void
-runtime_init_connect_signals( NactIAdvancedTab *instance, GtkTreeView *listview )
+runtime_init_connect_signals( NactISchemesTab *instance, GtkTreeView *listview )
 {
-	static const gchar *thisfn = "nact_iadvanced_tab_runtime_init_connect_signals";
+	static const gchar *thisfn = "nact_ischemes_tab_runtime_init_connect_signals";
 
 	if( st_initialized && !st_finalized ){
 
 		g_debug( "%s: instance=%p, listview=%p", thisfn, ( void * ) instance, ( void * ) listview );
-		g_return_if_fail( NACT_IS_IADVANCED_TAB( instance ));
+		g_return_if_fail( NACT_IS_ISCHEMES_TAB( instance ));
 
 		base_window_signal_connect(
 				BASE_WINDOW( instance ),
@@ -183,26 +183,26 @@ runtime_init_connect_signals( NactIAdvancedTab *instance, GtkTreeView *listview
 }
 
 void
-nact_iadvanced_tab_all_widgets_showed( NactIAdvancedTab *instance )
+nact_ischemes_tab_all_widgets_showed( NactISchemesTab *instance )
 {
-	static const gchar *thisfn = "nact_iadvanced_tab_all_widgets_showed";
+	static const gchar *thisfn = "nact_ischemes_tab_all_widgets_showed";
 
 	if( st_initialized && !st_finalized ){
 
 		g_debug( "%s: instance=%p", thisfn, ( void * ) instance );
-		g_return_if_fail( NACT_IS_IADVANCED_TAB( instance ));
+		g_return_if_fail( NACT_IS_ISCHEMES_TAB( instance ));
 	}
 }
 
 void
-nact_iadvanced_tab_dispose( NactIAdvancedTab *instance )
+nact_ischemes_tab_dispose( NactISchemesTab *instance )
 {
-	static const gchar *thisfn = "nact_iadvanced_tab_dispose";
+	static const gchar *thisfn = "nact_ischemes_tab_dispose";
 
 	if( st_initialized && !st_finalized ){
 
 		g_debug( "%s: instance=%p", thisfn, ( void * ) instance );
-		g_return_if_fail( NACT_IS_IADVANCED_TAB( instance ));
+		g_return_if_fail( NACT_IS_ISCHEMES_TAB( instance ));
 
 		nact_schemes_list_dispose( BASE_WINDOW( instance ));
 	}
@@ -213,12 +213,12 @@ nact_iadvanced_tab_dispose( NactIAdvancedTab *instance )
  * The caller should call na_core_utils_slist_free() after use.
  */
 GSList *
-nact_iadvanced_tab_get_schemes( NactIAdvancedTab *instance )
+nact_ischemes_tab_get_schemes( NactISchemesTab *instance )
 {
 	GSList *list;
 
 	list = NULL;
-	g_return_val_if_fail( NACT_IS_IADVANCED_TAB( instance ), list );
+	g_return_val_if_fail( NACT_IS_ISCHEMES_TAB( instance ), list );
 
 	if( st_initialized && !st_finalized ){
 
@@ -229,9 +229,9 @@ nact_iadvanced_tab_get_schemes( NactIAdvancedTab *instance )
 }
 
 static void
-on_tab_updatable_selection_changed( NactIAdvancedTab *instance, gint count_selected )
+on_tab_updatable_selection_changed( NactISchemesTab *instance, gint count_selected )
 {
-	static const gchar *thisfn = "nact_iadvanced_tab_on_tab_updatable_selection_changed";
+	static const gchar *thisfn = "nact_ischemes_tab_on_tab_updatable_selection_changed";
 	NAObjectItem *item;
 	NAObjectProfile *profile;
 	gboolean enable_tab;
@@ -242,7 +242,7 @@ on_tab_updatable_selection_changed( NactIAdvancedTab *instance, gint count_selec
 	if( st_initialized && !st_finalized ){
 
 		g_debug( "%s: instance=%p, count_selected=%d", thisfn, ( void * ) instance, count_selected );
-		g_return_if_fail( NACT_IS_IADVANCED_TAB( instance ));
+		g_return_if_fail( NACT_IS_ISCHEMES_TAB( instance ));
 
 		g_object_get(
 				G_OBJECT( instance ),
@@ -267,21 +267,21 @@ on_tab_updatable_selection_changed( NactIAdvancedTab *instance, gint count_selec
 }
 
 static void
-on_tab_updatable_enable_tab( NactIAdvancedTab *instance, NAObjectItem *item )
+on_tab_updatable_enable_tab( NactISchemesTab *instance, NAObjectItem *item )
 {
-	static const gchar *thisfn = "nact_iadvanced_tab_on_tab_updatable_enable_tab";
+	static const gchar *thisfn = "nact_ischemes_tab_on_tab_updatable_enable_tab";
 
 	if( st_initialized && !st_finalized ){
 
 		g_debug( "%s: instance=%p, item=%p", thisfn, ( void * ) instance, ( void * ) item );
-		g_return_if_fail( NACT_IS_IADVANCED_TAB( instance ));
+		g_return_if_fail( NACT_IS_ISCHEMES_TAB( instance ));
 
 		tab_set_sensitive( instance );
 	}
 }
 
 static gboolean
-tab_set_sensitive( NactIAdvancedTab *instance )
+tab_set_sensitive( NactISchemesTab *instance )
 {
 	NAObjectItem *item;
 	NAObjectProfile *profile;
@@ -294,13 +294,13 @@ tab_set_sensitive( NactIAdvancedTab *instance )
 			NULL );
 
 	enable_tab = ( profile != NULL && na_object_is_target_selection( NA_OBJECT_ACTION( item )));
-	nact_main_tab_enable_page( NACT_MAIN_WINDOW( instance ), TAB_ADVANCED, enable_tab );
+	nact_main_tab_enable_page( NACT_MAIN_WINDOW( instance ), TAB_SCHEMES, enable_tab );
 
 	return( enable_tab );
 }
 
 static GtkTreeView *
-get_schemes_tree_view( NactIAdvancedTab *instance )
+get_schemes_tree_view( NactISchemesTab *instance )
 {
 	GtkWidget *treeview;
 
diff --git a/src/nact/nact-main-tab.h b/src/nact/nact-main-tab.h
index 674a1ae..657d4b1 100644
--- a/src/nact/nact-main-tab.h
+++ b/src/nact/nact-main-tab.h
@@ -63,7 +63,7 @@ enum {
 	TAB_COMMAND,
 	TAB_FOLDERS,
 	TAB_CONDITIONS,
-	TAB_ADVANCED,
+	TAB_SCHEMES,
 	TAB_PROPERTIES
 };
 
diff --git a/src/nact/nact-main-window.c b/src/nact/nact-main-window.c
index 90c0ade..48e7dc0 100644
--- a/src/nact/nact-main-window.c
+++ b/src/nact/nact-main-window.c
@@ -51,8 +51,8 @@
 #include "nact-icommand-tab.h"
 #include "nact-ifolders-tab.h"
 #include "nact-iconditions-tab.h"
-#include "nact-iadvanced-tab.h"
 #include "nact-iproperties-tab.h"
+#include "nact-ischemes-tab.h"
 #include "nact-main-tab.h"
 #include "nact-main-menubar.h"
 #include "nact-main-statusbar.h"
@@ -148,7 +148,7 @@ static void     iaction_tab_iface_init( NactIActionTabInterface *iface );
 static void     icommand_tab_iface_init( NactICommandTabInterface *iface );
 static void     ifolders_tab_iface_init( NactIFoldersTabInterface *iface );
 static void     iconditions_tab_iface_init( NactIConditionsTabInterface *iface );
-static void     iadvanced_tab_iface_init( NactIAdvancedTabInterface *iface );
+static void     ischemes_tab_iface_init( NactISchemesTabInterface *iface );
 static void     iproperties_tab_iface_init( NactIPropertiesTabInterface *iface );
 static void     iabout_iface_init( NAIAboutInterface *iface );
 static void     ipivot_consumer_iface_init( NAIPivotConsumerInterface *iface );
@@ -247,8 +247,8 @@ register_type( void )
 		NULL
 	};
 
-	static const GInterfaceInfo iadvanced_tab_iface_info = {
-		( GInterfaceInitFunc ) iadvanced_tab_iface_init,
+	static const GInterfaceInfo ischemes_tab_iface_info = {
+		( GInterfaceInitFunc ) ischemes_tab_iface_init,
 		NULL,
 		NULL
 	};
@@ -291,7 +291,7 @@ register_type( void )
 
 	g_type_add_interface_static( type, NACT_ICONDITIONS_TAB_TYPE, &iconditions_tab_iface_info );
 
-	g_type_add_interface_static( type, NACT_IADVANCED_TAB_TYPE, &iadvanced_tab_iface_info );
+	g_type_add_interface_static( type, NACT_ISCHEMES_TAB_TYPE, &ischemes_tab_iface_info );
 
 	g_type_add_interface_static( type, NACT_IPROPERTIES_TAB_TYPE, &iproperties_tab_iface_info );
 
@@ -533,9 +533,9 @@ iconditions_tab_iface_init( NactIConditionsTabInterface *iface )
 }
 
 static void
-iadvanced_tab_iface_init( NactIAdvancedTabInterface *iface )
+ischemes_tab_iface_init( NactISchemesTabInterface *iface )
 {
-	static const gchar *thisfn = "nact_main_window_iadvanced_tab_iface_init";
+	static const gchar *thisfn = "nact_main_window_ischemes_tab_iface_init";
 
 	g_debug( "%s: iface=%p", thisfn, ( void * ) iface );
 }
@@ -730,7 +730,7 @@ instance_dispose( GObject *window )
 		nact_icommand_tab_dispose( NACT_ICOMMAND_TAB( window ));
 		nact_ifolders_tab_dispose( NACT_IFOLDERS_TAB( window ));
 		nact_iconditions_tab_dispose( NACT_ICONDITIONS_TAB( window ));
-		nact_iadvanced_tab_dispose( NACT_IADVANCED_TAB( window ));
+		nact_ischemes_tab_dispose( NACT_ISCHEMES_TAB( window ));
 		nact_iproperties_tab_dispose( NACT_IPROPERTIES_TAB( window ));
 		nact_main_menubar_dispose( self );
 
@@ -1054,7 +1054,7 @@ on_base_initial_load_toplevel( NactMainWindow *window, gpointer user_data )
 		nact_icommand_tab_initial_load_toplevel( NACT_ICOMMAND_TAB( window ));
 		nact_ifolders_tab_initial_load_toplevel( NACT_IFOLDERS_TAB( window ));
 		nact_iconditions_tab_initial_load_toplevel( NACT_ICONDITIONS_TAB( window ));
-		nact_iadvanced_tab_initial_load_toplevel( NACT_IADVANCED_TAB( window ));
+		nact_ischemes_tab_initial_load_toplevel( NACT_ISCHEMES_TAB( window ));
 		nact_iproperties_tab_initial_load_toplevel( NACT_IPROPERTIES_TAB( window ));
 
 		nact_main_statusbar_initial_load_toplevel( window );
@@ -1092,7 +1092,7 @@ on_base_runtime_init_toplevel( NactMainWindow *window, gpointer user_data )
 		nact_icommand_tab_runtime_init_toplevel( NACT_ICOMMAND_TAB( window ));
 		nact_ifolders_tab_runtime_init_toplevel( NACT_IFOLDERS_TAB( window ));
 		nact_iconditions_tab_runtime_init_toplevel( NACT_ICONDITIONS_TAB( window ));
-		nact_iadvanced_tab_runtime_init_toplevel( NACT_IADVANCED_TAB( window ));
+		nact_ischemes_tab_runtime_init_toplevel( NACT_ISCHEMES_TAB( window ));
 		nact_iproperties_tab_runtime_init_toplevel( NACT_IPROPERTIES_TAB( window ));
 		nact_main_menubar_runtime_init( window );
 
@@ -1132,7 +1132,7 @@ on_base_all_widgets_showed( NactMainWindow *window, gpointer user_data )
 	g_return_if_fail( NACT_IS_ICOMMAND_TAB( window ));
 	g_return_if_fail( NACT_IS_IFOLDERS_TAB( window ));
 	g_return_if_fail( NACT_IS_ICONDITIONS_TAB( window ));
-	g_return_if_fail( NACT_IS_IADVANCED_TAB( window ));
+	g_return_if_fail( NACT_IS_ISCHEMES_TAB( window ));
 	g_return_if_fail( NACT_IS_IPROPERTIES_TAB( window ));
 
 	if( !window->private->dispose_has_run ){
@@ -1141,7 +1141,7 @@ on_base_all_widgets_showed( NactMainWindow *window, gpointer user_data )
 		nact_icommand_tab_all_widgets_showed( NACT_ICOMMAND_TAB( window ));
 		nact_ifolders_tab_all_widgets_showed( NACT_IFOLDERS_TAB( window ));
 		nact_iconditions_tab_all_widgets_showed( NACT_ICONDITIONS_TAB( window ));
-		nact_iadvanced_tab_all_widgets_showed( NACT_IADVANCED_TAB( window ));
+		nact_ischemes_tab_all_widgets_showed( NACT_ISCHEMES_TAB( window ));
 		nact_iproperties_tab_all_widgets_showed( NACT_IPROPERTIES_TAB( window ));
 
 		nact_iactions_list_all_widgets_showed( NACT_IACTIONS_LIST( window ));



[Date Prev][Date Next]   [Thread Prev][Thread Next]   [Thread Index] [Date Index] [Author Index]
diff --git a/src/nact/nact-iadvanced-tab.h b/src/nact/nact-ischemes-tab.h
similarity index 50%
rename from src/nact/nact-iadvanced-tab.h
rename to src/nact/nact-ischemes-tab.h
index 317bd6f..b66b37b 100644
--- a/src/nact/nact-iadvanced-tab.h
+++ b/src/nact/nact-ischemes-tab.h
@@ -28,13 +28,13 @@
  *   ... and many others (see AUTHORS)
  */
 
-#ifndef __NACT_IADVANCED_TAB_H__
-#define __NACT_IADVANCED_TAB_H__
+#ifndef __NACT_ISCHEMES_TAB_H__
+#define __NACT_ISCHEMES_TAB_H__
 
 /**
  * SECTION: nact_iadvanced_tab
  * @short_description: #NactIAdvancedTab interface declaration.
  * @include: nact/nact-iadvanced-tab.h
  *
  * This interface implements all the widgets which define the
  * conditions for the action.
@@ -44,30 +44,30 @@
 
 G_BEGIN_DECLS
 
-#define NACT_IADVANCED_TAB_TYPE							( nact_iadvanced_tab_get_type())
-#define NACT_IADVANCED_TAB( object )					( G_TYPE_CHECK_INSTANCE_CAST( object, NACT_IADVANCED_TAB_TYPE, NactIAdvancedTab ))
-#define NACT_IS_IADVANCED_TAB( object )					( G_TYPE_CHECK_INSTANCE_TYPE( object, NACT_IADVANCED_TAB_TYPE ))
-#define NACT_IADVANCED_TAB_GET_INTERFACE( instance )	( G_TYPE_INSTANCE_GET_INTERFACE(( instance ), NACT_IADVANCED_TAB_TYPE, NactIAdvancedTabInterface ))
+#define NACT_ISCHEMES_TAB_TYPE						( nact_ischemes_tab_get_type())
+#define NACT_ISCHEMES_TAB( object )					( G_TYPE_CHECK_INSTANCE_CAST( object, NACT_ISCHEMES_TAB_TYPE, NactISchemesTab ))
+#define NACT_IS_ISCHEMES_TAB( object )				( G_TYPE_CHECK_INSTANCE_TYPE( object, NACT_ISCHEMES_TAB_TYPE ))
+#define NACT_ISCHEMES_TAB_GET_INTERFACE( instance )	( G_TYPE_INSTANCE_GET_INTERFACE(( instance ), NACT_ISCHEMES_TAB_TYPE, NactISchemesTabInterface ))
 
-typedef struct NactIAdvancedTab NactIAdvancedTab;
+typedef struct NactISchemesTab                 NactISchemesTab;
 
-typedef struct NactIAdvancedTabInterfacePrivate NactIAdvancedTabInterfacePrivate;
+typedef struct NactISchemesTabInterfacePrivate NactISchemesTabInterfacePrivate;
 
 typedef struct {
-	GTypeInterface                    parent;
-	NactIAdvancedTabInterfacePrivate *private;
+	GTypeInterface                   parent;
+	NactISchemesTabInterfacePrivate *private;
 }
-	NactIAdvancedTabInterface;
+	NactISchemesTabInterface;
 
-GType   nact_iadvanced_tab_get_type( void );
+GType   nact_ischemes_tab_get_type( void );
 
-void    nact_iadvanced_tab_initial_load_toplevel( NactIAdvancedTab *instance );
-void    nact_iadvanced_tab_runtime_init_toplevel( NactIAdvancedTab *instance );
-void    nact_iadvanced_tab_all_widgets_showed( NactIAdvancedTab *instance );
-void    nact_iadvanced_tab_dispose( NactIAdvancedTab *instance );
+void    nact_ischemes_tab_initial_load_toplevel( NactISchemesTab *instance );
+void    nact_ischemes_tab_runtime_init_toplevel( NactISchemesTab *instance );
+void    nact_ischemes_tab_all_widgets_showed( NactISchemesTab *instance );
+void    nact_ischemes_tab_dispose( NactISchemesTab *instance );
 
-GSList *nact_iadvanced_tab_get_schemes( NactIAdvancedTab *instance );
+GSList *nact_ischemes_tab_get_schemes( NactISchemesTab *instance );
 
 G_END_DECLS
 
-#endif /* __NACT_IADVANCED_TAB_H__ */
+#endif /* __NACT_ISCHEMES_TAB_H__ */
@@ -28,13 +28,13 @@
 
 /**
- * SECTION: nact_iadvanced_tab
- * @short_description: #NactIAdvancedTab interface declaration.
- * @include: nact/nact-iadvanced-tab.h
+ * SECTION: nact_ischemes_tab
+ * @short_description: #NactISchemesTab interface declaration.
+ * @include: nact/nact-ischemes-tab.h
  *
  * This interface implements all the widgets which define the